@@ -1,5 +1,5 @@
 /* This file is part of YAZ proxy
-   Copyright (C) 1998-2009 Index Data
+   Copyright (C) 1998-2011 Index Data
 
 YAZ proxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -43,7 +43,11 @@ int Yaz_usemarcon::convert(const char *stage1, const char *stage2,
     if (stage1 && *stage1)
     {
         char *converted;
+#if RULE_VERSION >= 314
+        size_t convlen;
+#else
         int convlen;
+#endif
         if (!m_stage1)
         {
             m_stage1 = new Usemarcon();
